pub enum Cmd {
Show 14 variants
List {
timeout_ms: u64,
iface: Option<IfaceSelector>,
},
Get {
ip: Option<Ipv4Addr>,
index: Option<usize>,
name: String,
},
Xml {
ip: Option<Ipv4Addr>,
index: Option<usize>,
iface: Option<IfaceSelector>,
out: Option<PathBuf>,
},
Report {
ip: Option<Ipv4Addr>,
index: Option<usize>,
iface: Option<IfaceSelector>,
out: PathBuf,
stdout: bool,
timeout_ms: u64,
no_xml: bool,
},
Set {
ip: Option<Ipv4Addr>,
index: Option<usize>,
name: String,
value: String,
},
Stream {
ip: Option<Ipv4Addr>,
index: Option<usize>,
iface: Option<IfaceSelector>,
mode: String,
group: Option<Ipv4Addr>,
port: u16,
auto: bool,
packet_size: Option<u32>,
save: usize,
rgb: bool,
duration_s: u64,
},
Events {
ip: Option<Ipv4Addr>,
index: Option<usize>,
iface: Option<IfaceSelector>,
port: u16,
enable: String,
count: u32,
},
Chunks {
ip: Option<Ipv4Addr>,
index: Option<usize>,
enable: bool,
selectors: String,
},
Bench {
ip: Option<Ipv4Addr>,
index: Option<usize>,
iface: Option<IfaceSelector>,
mode: String,
group: Option<Ipv4Addr>,
port: u16,
duration_s: u64,
json_out: Option<PathBuf>,
},
SetIp {
mac: String,
ip: Ipv4Addr,
subnet: Ipv4Addr,
gateway: Ipv4Addr,
force: bool,
},
ListUsb,
GetUsb {
index: Option<usize>,
name: String,
},
SetUsb {
index: Option<usize>,
name: String,
value: String,
},
StreamUsb {
index: Option<usize>,
save: usize,
rgb: bool,
duration_s: u64,
},
}Variants
List
Discover cameras (GVCP)
Get
Read a feature via GenApi NodeMap
Xml
Dump the camera’s GenApi XML (no parsing, so a document we cannot read still comes out)
Fields
iface: Option<IfaceSelector>Host interface, by IPv4 address or by OS name
Report
Collect a diagnostic bundle to attach to a bug report
Fields
iface: Option<IfaceSelector>Host interface, by IPv4 address or by OS name
Set
Write a feature via GenApi NodeMap
Stream
Start GVSP stream (uni-/multicast)
Fields
iface: Option<IfaceSelector>Host interface, by IPv4 address or by OS name
auto: boolSet GevSCPSPacketSize from the host NIC MTU, then path-probe (ADR-0021). Mutually exclusive with –packet-size. Default is to leave the camera’s current value alone.
Events
Configure + read events (message channel)
Fields
iface: Option<IfaceSelector>Host interface, by IPv4 address or by OS name
Chunks
Toggle ChunkModeActive + selectors
Bench
Sustained stream soak/benchmark
Fields
iface: Option<IfaceSelector>Host interface, by IPv4 address or by OS name
SetIp
Configure IP address of a GigE camera
Fields
ListUsb
Discover USB3 Vision cameras
GetUsb
Read a feature from a USB3 Vision camera
SetUsb
Write a feature to a USB3 Vision camera
StreamUsb
Stream frames from a USB3 Vision camera